@@ -1,49 +1,50 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
 from trytond.model import ModelView, ModelSQL, fields
+from trytond.pyson import Get, Eval, And, Bool, Not, Or
 from decimal import Decimal
 
 
 class Party(ModelSQL, ModelView):
     _name = 'party.party'
-    account_payable = fields.Property(type='many2one',
-            relation='account.account', string='Account Payable',
-            domain=[('kind', '=', 'payable'),
-                "('company', '=', globals().get('company', 0))"],
-            states={
-                'required': "globals().get('company') and bool(company)",
-                'invisible': "not globals().get('company') or not bool(company)",
-            })
-    account_receivable = fields.Property(type='many2one',
-            relation='account.account', string='Account Receivable',
-            domain=[('kind', '=', 'receivable'),
-                "('company', '=', globals().get('company', 0))"],
-            states={
-                'required': "globals().get('company') and bool(company)",
-                'invisible': "not globals().get('company') or not bool(company)",
-            })
-    customer_tax_rule = fields.Property(type='many2one',
-            relation='account.tax.rule', string='Customer Tax Rule',
-            domain=["('company', '=', globals().get('company', 0))"],
-            states={
-                'invisible': "not globals().get('company') or not bool(company)",
-            }, help='Apply this rule on taxes when party is customer.')
-    supplier_tax_rule = fields.Property(type='many2one',
-            relation='account.tax.rule', string='Supplier Tax Rule',
-            domain=["('company', '=', globals().get('company', 0))"],
-            states={
-                'invisible': "not globals().get('company') or not bool(company)",
-            }, help='Apply this rule on taxes when party is supplier.')
-    receivable = fields.Function('get_receivable_payable',
-            fnct_search='search_receivable_payable', string='Receivable')
-    payable = fields.Function('get_receivable_payable',
-            fnct_search='search_receivable_payable', string='Payable')
-    receivable_today = fields.Function('get_receivable_payable',
-            fnct_search='search_receivable_payable', string='Receivable Today')
-    payable_today = fields.Function('get_receivable_payable',
-            fnct_search='search_receivable_payable', string='Payable Today')
+    account_payable = fields.Property(fields.Many2One('account.account',
+        'Account Payable', domain=[
+            ('kind', '=', 'payable'),
+            ('company', '=', Eval('company')),
+        ],
+        states={
+            'required': Bool(Eval('company')),
+            'invisible': Not(Bool(Eval('company'))),
+        }))
+    account_receivable = fields.Property(fields.Many2One('account.account',
+        'Account Receivable', domain=[
+            ('kind', '=', 'receivable'),
+            ('company', '=', Eval('company')),
+        ],
+        states={
+            'required': Bool(Eval('company')),
+            'invisible': Not(Bool(Eval('company'))),
+        }))
+    customer_tax_rule = fields.Property(fields.Many2One('account.tax.rule',
+        'Customer Tax Rule', domain=[('company', '=', Eval('company'))],
+        states={
+            'invisible': Not(Bool(Eval('company'))),
+        }, help='Apply this rule on taxes when party is customer.'))
+    supplier_tax_rule = fields.Property(fields.Many2One('account.tax.rule',
+        'Supplier Tax Rule', domain=[('company', '=', Eval('company'))],
+        states={
+            'invisible': Not(Bool(Eval('company'))),
+        }, help='Apply this rule on taxes when party is supplier.'))
+    receivable = fields.Function(fields.Numeric('Receivable'),
+            'get_receivable_payable', searcher='search_receivable_payable')
+    payable = fields.Function(fields.Numeric('Payable'),
+            'get_receivable_payable', searcher='search_receivable_payable')
+    receivable_today = fields.Function(fields.Numeric('Receivable Today'),
+            'get_receivable_payable', searcher='search_receivable_payable')
+    payable_today = fields.Function(fields.Numeric('Payable Today'),
+            'get_receivable_payable', searcher='search_receivable_payable')
 
-    def get_receivable_payable(self, cursor, user_id, ids, names, arg,
+    def get_receivable_payable(self, cursor, user_id, ids, names,
             context=None):
         '''
         Function to compute receivable, payable (today or not) for party ids.
@@ -124,10 +125,8 @@ class Party(ModelSQL, ModelView):
                 res[name][party_id] = sum
         return res
 
-    def search_receivable_payable(self, cursor, user_id, name, args,
+    def search_receivable_payable(self, cursor, user_id, name, clause,
             context=None):
-        if not len(args):
-            return []
         move_line_obj = self.pool.get('account.move.line')
         company_obj = self.pool.get('company.company')
         user_obj = self.pool.get('res.user')
@@ -166,22 +165,21 @@ class Party(ModelSQL, ModelView):
 
         line_query, _ = move_line_obj.query_get(cursor, user_id, context=context)
 
-        cursor.execute('SELECT l.party ' \
-                'FROM account_move_line AS l, ' \
-                    'account_account AS a ' \
-                'WHERE a.id = l.account ' \
-                    'AND a.active ' \
-                    'AND a.kind = %s ' \
-                    'AND l.party IS NOT NULL ' \
-                    'AND l.reconciliation IS NULL ' \
+        cursor.execute('SELECT l.party '
+                'FROM account_move_line AS l, '
+                    'account_account AS a '
+                'WHERE a.id = l.account '
+                    'AND a.active '
+                    'AND a.kind = %s '
+                    'AND l.party IS NOT NULL '
+                    'AND l.reconciliation IS NULL '
                     'AND ' + line_query + ' ' \
                     + today_query + \
-                    'AND a.company = %s ' \
-                'GROUP BY l.party ' \
-                'HAVING ' + \
-                    'AND'.join('(SUM((COALESCE(l.debit, 0) - COALESCE(l.credit, 0))) ' \
-                        + ' ' + x[1] + ' %s) ' for x in args),
-                    [code] + today_value + [company_id] + [Decimal(x[2]) for x in args])
+                    'AND a.company = %s '
+                'GROUP BY l.party '
+                'HAVING (SUM((COALESCE(l.debit, 0) - COALESCE(l.credit, 0))) ' \
+                        + clause[1] + ' %s)',
+                    [code] + today_value + [company_id] + [Decimal(clause[2])])
         return [('id', 'in', [x[0] for x in cursor.fetchall()])]
 
 Party()
